@@ -2,12 +2,11 @@ import shutil
 from pathlib import Path
 
 import cv2 as cv
-from prettytable import PrettyTable
-from tqdm import tqdm
-
 import fiftyone as fo
 from fiftyone import ViewField as F
 from fiftyone.utils.labels import segmentations_to_detections
+from prettytable import PrettyTable
+from tqdm import tqdm
 
 
 def _map_detections(field_data, mapping):
@@ -73,11 +72,11 @@ def gen_label_mapping(old_classes, new_classes):
     """Generate detections mapping.
 
     Args:
-        old_classes (list): `['c0', 'c1', 'c2', 'c3', 'c4', 'c5', 'background']`
-        new_classes (list): `['c0', 'c1', 'c2', ['c3', 'c4', 'c5'], 'background']`
+        old_classes (list): ``['c0', 'c1', 'c2', 'c3', 'c4', 'c5', 'background']``
+        new_classes (list): ``['c0', 'c1', 'c2', ['c3', 'c4', 'c5'], 'background']``
 
     Returns:
-        _type_: _description_
+        a :class:`dict`
     """
     old_classes, new_classes = old_classes[:-1], new_classes[:-1]
 
@@ -100,11 +99,11 @@ def gen_mask_mapping(old_classes, new_classes):
     """Generate segmentation mapping.
 
     Args:
-        old_classes (list): `['c0', 'c1', 'c2', 'c3', 'c4', 'c5', 'be ignored']`
-        new_classes (list): `['c0', 'c1', 'c2', ['c3', 'c4', 'c5'], 'be ignored']`
+        old_classes (list): ``['c0', 'c1', 'c2', 'c3', 'c4', 'c5', 'be ignored']``
+        new_classes (list): ``['c0', 'c1', 'c2', ['c3', 'c4', 'c5'], 'be ignored']``
 
     Returns:
-        _type_: _description_
+        a :class:`dict`
     """
     old_classes, new_classes = old_classes[:-1], new_classes[:-1]
 
@@ -128,13 +127,13 @@ def filter_detections_dataset(dataset, new_classes=None, field_name="ground_trut
     """Steps: map labels -> check dataset.classes -> filter valid samples
 
     Args:
-        dataset (fo.Dataset): _description_
-        new_classes (list, optional): refer to `gen_label_mapping()`. Defaults to None.
-        field_name (str, optional): _description_. Defaults to "ground_truth".
-        background (str, optional): _description_. Defaults to "background".
+        dataset: a :class:`fiftyone.core.dataset.Dataset`
+        new_classes (None): refer to :func:`gen_label_mapping`
+        field_name (str, optional): defaults to "ground_truth"
+        background (str, optional): defaults to "background"
 
     Returns:
-        fo.Dataset: _description_
+        a :class:`fiftyone.core.dataset.Dataset`
     """
     dataset.save()
     dataset = dataset.clone()
@@ -154,13 +153,13 @@ def filter_segmentation_dataset(dataset, new_classes=None, field_name="ground_tr
     """Steps: map labels -> check dataset.mask_targets -> filter valid samples
 
     Args:
-        dataset (fo.Dataset): _description_
-        new_classes (list, optional): refer to `gen_mask_mapping()`. Defaults to None.
-        field_name (str, optional): _description_. Defaults to "ground_truth".
-        ignore_index (int, optional): _description_. Defaults to 255.
+        dataset: a :class:`fiftyone.core.dataset.Dataset`
+        new_classes (None): refer to :func:`gen_mask_mapping`
+        field_name (str, optional): defaults to "ground_truth"
+        ignore_index (int, optional): defaults to 255
 
     Returns:
-        fo.Dataset: _description_
+        a :class:`fiftyone.core.dataset.Dataset`
     """
     dataset.save()
     dataset = dataset.clone()
@@ -216,23 +215,36 @@ def count_values(dataset, field_or_expr, ordered=True):
     return count_label
 
 
-def split_dataset(dataset, splits=None, limit=3000, field_name="ground_truth", from_field=None):
-    dataset.untag_samples(dataset.distinct("tags"))
-    dataset = dataset.shuffle()
+def split_dataset(dataset, splits=None, limit=3000, seed=51, field_name="ground_truth", from_field=None):
+    """Adds the split tags to all samples in this dataset.
+
+    Args:
+        dataset: a :class:`fiftyone.core.dataset.Dataset`
+        splits (dict, optional): defaults to None
+        limit (int, optional): defaults to 3000
+        seed (int, optional): defaults to 51
+        field_name (str, optional): defaults to "ground_truth"
+        from_field (str, optional): defaults to None
+
+    Returns:
+        a :class:`DatasetView`
+    """
+    view = dataset.shuffle(seed=seed)
+    view.untag_samples(["train", "val", "test"])
 
     if from_field is not None:
         print("todo: segmentations_to_detections()")
-        segmentations_to_detections(dataset, from_field, field_name, mask_targets=dataset.default_mask_targets, mask_types="stuff")
+        segmentations_to_detections(view, from_field, field_name, mask_targets=view.default_mask_targets, mask_types="stuff")
 
     if splits is None:
         splits = {"val": 0.1, "train": 0.9}
 
     val_ids, train_ids = [], []
-    for label, _ in count_values(dataset, f"{field_name}.detections.label", ordered=True):
+    for label, _ in count_values(view, f"{field_name}.detections.label", ordered=True):
         _detections = F(f"{field_name}.detections").filter(F("label") == label)
-        view = dataset.exclude(val_ids + train_ids).match(_detections.length() > 0)
+        subset = view.exclude(val_ids + train_ids).match(_detections.length() > 0)
 
-        ids = view.take(limit).values("id")
+        ids = subset.take(limit).values("id")
 
         pos_val = splits.get("val", 0.1)
         pos_train = splits.get("train", 0.9)
@@ -245,11 +257,11 @@ def split_dataset(dataset, splits=None, limit=3000, field_name="ground_truth", f
         val_ids.extend(ids[:pos_val])
         train_ids.extend(ids[pos_val:])
 
-    dataset.select(val_ids).tag_samples("val")
-    dataset.select(train_ids).tag_samples("train")
-    dataset.exclude(val_ids + train_ids).tag_samples("test")
-    print(count_values(dataset, "tags", ordered=True))
-    return dataset
+    view.select(val_ids).tag_samples("val")
+    view.select(train_ids).tag_samples("train")
+    view.exclude(val_ids + train_ids).tag_samples("test")
+    print(count_values(view, "tags", ordered=True))
+    return view
 
 
 def filter_segmentation_samples(out_dir, data_root, classes, mask_targets, threshold=0.05, splits=["train", "val"],
@@ -271,12 +283,15 @@ def filter_segmentation_samples(out_dir, data_root, classes, mask_targets, thres
         data_root (str): _description_
         classes (list[str]): _description_
         mask_targets (dict[int, str]): _description_
-        threshold (float, optional): _description_. Defaults to 0.05.
-        splits (list, optional): _description_. Defaults to ["train", "val"].
-        img_dir (str, optional): _description_. Defaults to "data".
-        ann_dir (str, optional): _description_. Defaults to "labels".
-        img_suffix (str, optional): _description_. Defaults to ".jpg".
-        seg_map_suffix (str, optional): _description_. Defaults to ".png".
+        threshold (float, optional): _description_. Defaults to 0.05
+        splits (list, optional): _description_. Defaults to ["train", "val"]
+        img_dir (str, optional): _description_. Defaults to "data"
+        ann_dir (str, optional): _description_. Defaults to "labels"
+        img_suffix (str, optional): _description_. Defaults to ".jpg"
+        seg_map_suffix (str, optional): _description_. Defaults to ".png"
+
+    Returns:
+        a :class:`str`
     """
     _mapping = {name: index for index, name in mask_targets.items()}
     _labels = [_mapping[name] for name in classes]
